==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/obj_input.js <==
/*****************************************************
 * Extension script: Input form object
 *
 * INHERITS FROM obj_form_generic
 *    _me._value
 *    _me._disabled
 *    _me.__update
 *
 * EVN: _onblur
 *      _onfocus
 *      _onsubmit
 *      _onclose
 *      _onerror
 *
 *****************************************************/
 
_me = obj_input.prototype;
function obj_input(){};

/**
 * @brief: CONSTRUCTOR, create input form object to __eIN variable
 * @date : 20.4.2006 17:24:21
 **/
_me.__constructor = function(){
    var me = this;
	// error buffer
	this._checkError = [];

	/* creates ELM directly, because simlicity of object */
	var elm = mkElement('input',{"type":'text',"name":this._pathName+'main',"id":this._pathName+'main',"className":this._type!='obj_input'?'obj_input '+this._type:'obj_input'});
	if (this._type == 'obj_password') elm.setAttribute('type','password');
	this._main.appendChild(elm);
	this.__eIN = elm.form[elm.name];

	this.__eIN.setAttribute('autocomplete',"off");

	/* KEY DOWN */
	this.__eIN.onkeydown = function(e){
		var e = e || window.event;

		switch (e.keyCode) {
			// Enter
			case 13:
				if (me._onsubmit) me._onsubmit(e);
				break;
			// Esc
			case 27:
				if (me._onclose) return me._onclose(e);
				break;
			// Tab
			case 9 : break;
		}

		if (me._onkeydown) return me._onkeydown(e);
        
		me.__exeEvent('onkeydown',e,{"owner":me});
		
		return e.keyCode==13?false:true;
	};

	// ONBLUR
	this.__eIN.onblur = function(e){
		var e = e || window.event;
		if (me._onblur) return me._onblur(e);

		me.__exeEvent('onblur',e,{"owner":me});
		return true;
	};

	// ONFOCUS
	this.__eIN.onfocus = function(e){
		var e = e || window.event;
		if (me._onfocus) me._onfocus(e);

		me.__exeEvent('onfocus',e,{"owner":me});
		return true;
	};

	// ONKEYUP
	this.__eIN.onkeyup = function(e){
		var e = e || window.event;
		if (me._onkeyup) me._onkeyup(e);

		me.__exeEvent('onkeyup',e,{"owner":me});
		return true;
	};

	this.__eIN.onclick = function(e){
		var e = e || window.event;
		if (me._onclick) me._onclick(e);

		me.__exeEvent('onclick',e,{"owner":me});
		return true;
	};
	
	this._main.onfocus = function(er){
		me.__eIN.focus();
	};
};


_me._getCartPos = function(){
	/* MSIE */
	if (document.selection){
		var bookmark = "¨";
		var orig = this._value();
		var caretPos = document.selection.createRange();
		var sel = caretPos.text;

		caretPos.text = bookmark;

		// new line characters are two characters in IE and the cursor was 1 position off for each line
		var tmpText = this._value(); // pro textareu .replace(new RegExp(/\n/g), '');

		var i = tmpText.search(bookmark);
		this._value(orig);
		this._setRange(i,sel.length);

		return i;
	}
	/* OTHERS */
	else
		return this.__eIN.selectionStart;
};


_me._setRange = function(pos1,pos2){
	pos1 = pos1 || 0;

	/* MSIE */
	if (document.selection){
		var r = this.__eIN.createTextRange();
		r.collapse(true);
		r.moveStart("character", pos1);
		if (pos2) r.moveEnd("character", pos2);
		r.select();
	}
	/* OTHERS */
	else
		this.__eIN.setSelectionRange(pos1, pos2 || pos1);

	this.__eIN.focus();
};

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/obj_input.js <==
/*****************************************************
 * Extension script: Input form object
 *
 * INHERITS FROM obj_form_generic
 *    _me._value
 *    _me._disabled
 *    _me.__update
 *
 * EVN: _onblur
 *      _onfocus
 *      _onsubmit
 *      _onclose
 *      _onerror
 *
 *****************************************************/
 
_me = obj_input.prototype;
function obj_input(){};

/**
 * @brief: CONSTRUCTOR, create input form object to __eIN variable
 * @date : 20.4.2006 17:24:21
 **/
_me.__constructor = function(){
    var me = this;
	// error buffer
	this._checkError = [];

	/* creates ELM directly, because simlicity of object */
	var elm = mkElement('input',{"type":'text',"name":this._pathName+'main',"id":this._pathName+'main'});
	if (this._type == 'obj_password') elm.setAttribute('type','password');
	this._main.appendChild(elm);
	elm.className = this._type!='obj_input'?'obj_input '+this._type:'obj_input';

/*
	this._main.innerHTML = '<input type="'+ (this._type == 'obj_password'?'password':'text') +'" name="'+this._pathName+'main" id="'+this._pathName+'main" id="'+this._pathName+'main" class="'+ (this._type!='obj_input'?'obj_input '+this._type:'obj_input') +'" />';
	this.__eIN = this._main[this._pathName+'main'];
*/
	this.__eIN = elm.form[elm.name];
	elm = null;

	this.__eIN.setAttribute('autocomplete',"off");

	/* KEY DOWN */
	this.__eIN.onkeydown = function(e){
		var e = e || window.event;

		switch (e.keyCode) {
			// Enter
			case 13:
				if (me._onsubmit) me._onsubmit(e);
				break;
			// Esc
			case 27:
				if (me._onclose) return me._onclose(e);
				break;
			// Tab
			case 9 : break;
		}

		if (me._onkeydown) return me._onkeydown(e);
        
		me.__exeEvent('onkeydown',e,{"owner":me});
		
		return e.keyCode==13?false:true;
	};

	// ONBLUR
	this.__eIN.onblur = function(e){
		var e = e || window.event;
		if (me._onblur) return me._onblur(e);

		me.__exeEvent('onblur',e,{"owner":me});
		return true;
	};

	// ONFOCUS
	this.__eIN.onfocus = function(e){
		var e = e || window.event;
		if (me._onfocus) me._onfocus(e);

		me.__exeEvent('onfocus',e,{"owner":me});
		return true;
	};

	// ONKEYUP
	this.__eIN.onkeyup = function(e){
		var e = e || window.event;
		if (me._onkeyup) me._onkeyup(e);

		me.__exeEvent('onkeyup',e,{"owner":me});
		return true;
	};

	this.__eIN.onclick = function(e){
		var e = e || window.event;
		if (me._onclick) me._onclick(e);

		me.__exeEvent('onclick',e,{"owner":me});
		return true;
	};
	
	this._main.onfocus = function(er){
		me.__eIN.focus();
	};
};


_me._getCartPos = function(){
	/* MSIE */
	if (document.selection){
		var bookmark = "¨";
		var orig = this._value();
		var caretPos = document.selection.createRange();
		var sel = caretPos.text;

		caretPos.text = bookmark;

		// new line characters are two characters in IE and the cursor was 1 position off for each line
		var tmpText = this._value(); // pro textareu .replace(new RegExp(/\n/g), '');

		var i = tmpText.search(bookmark);
		this._value(orig);
		this._setRange(i,sel.length);

		return i;
	}
	/* OTHERS */
	else
		return this.__eIN.selectionStart;
};


_me._setRange = function(pos1,pos2){
	pos1 = pos1 || 0;

	/* MSIE */
	if (document.selection){
		var r = this.__eIN.createTextRange();
		r.collapse(true);
		r.moveStart("character", pos1);
		if (pos2) r.moveEnd("character", pos2);
		r.select();
	}
	/* OTHERS */
	else
		this.__eIN.setSelectionRange(pos1, pos2 || pos1);

	this.__eIN.focus();
};
